//
//  PhoneNumberPlugin.m
//  PhoneNumber
//
//  Created by Drabowska, Karolina on 05/12/16.
//  Copyright © 2016 Pegasystems. All rights reserved.
//

@import libPhoneNumberiOS;

#import "PhoneNumberPlugin.h"
static NSString *const kOnSuccess = @"onSuccess";
static NSString *const kOnFailure = @"onFailure";

@implementation PhoneNumberPlugin

+ (NSString *)name {
    return @"PhoneValidator";
}

- (void)provideJavaScriptWithCompletionHandler:(void (^)(NSString *_Nonnull))completionHandler {
    NSBundle *bundle = [NSBundle bundleForClass:[self class]];
    NSString *code = [NSString stringWithContentsOfFile:[bundle pathForResource:@"phoneValidator" ofType:@"js"] encoding:NSUTF8StringEncoding error:NULL];
    completionHandler(code);
}

#pragma mark - Called from JavaScript -

#pragma mark methods


- (void)isPossibleNumber:(id)data withCallback:(PMJavaScriptCallback *)callback{
    NBPhoneNumberUtil *phoneUtil = [[NBPhoneNumberUtil alloc] init];
    NSError *anError = nil;
    NBPhoneNumber *myNumber = [phoneUtil parse:data[@"phoneNumber"]
                                 defaultRegion:@"AT" error:&anError];
    if (anError == nil) {
        BOOL isValid = [phoneUtil isPossibleNumber:myNumber];
        if(isValid)
        {
            [self callback:callback notifySuccessWithData:@YES];
        }
        else
        {
            [self callback:callback notifySuccessWithData:@NO];

        }
    }
    else {
            [self callback:callback notifyFailureWithMessage:[anError localizedDescription]];
    }
}

- (void)getNumberType:(id)data withCallback:(PMJavaScriptCallback *)callback{
    NBPhoneNumberUtil *phoneUtil = [[NBPhoneNumberUtil alloc] init];
    NSError *anError = nil;
    NBPhoneNumber *myNumber = [phoneUtil parse:data[@"phoneNumber"]
                                 defaultRegion:@"AT" error:&anError];
    if (anError == nil) {
        NBEPhoneNumberType numerType = [phoneUtil getNumberType:myNumber];
        switch (numerType) {
            case NBEPhoneNumberTypeVOIP:
                [self callback:callback notifySuccessWithData:@"MOBILE or FIXED_LIN"];
            case NBEPhoneNumberTypeUAN:
                [self callback:callback notifySuccessWithData:@"Voice Mail Access Numbers"];
                break;
                
            default:
                 [self callback:callback notifySuccessWithData:@"Mobile"];
                break;
        }
    } else {
        [self callback:callback notifyFailureWithMessage:[anError localizedDescription]];
    }
    
}

#pragma mark - callbacks -

- (void)callback:(PMJavaScriptCallback *)callback notifySuccessWithData:(id)data {
    [callback call:kOnSuccess passingData:data];
}

- (void)callback:(PMJavaScriptCallback *)callback notifyFailureWithMessage:(NSString *)message {
    [callback call:kOnFailure passingData:@{ @"message" : message }];
}

@end
